%define gittag 02f0cdc

%{!?openmpiversion: %global openmpiversion 4.1.0}
%global openmpinumversion %( printf "%02d%02d%02d" `echo %{openmpiversion} | cut -d. -f1,2,3 --output-delimiter=" "` )
%{!?intelmpiversion: %global intelmpiversion 2021.1.1}

%bcond_without openmpi
%ifarch x86_64
%bcond_without impi
%else
%bcond_with impi
%endif

%if %{with openmpi}
%global mpi_list openmpi
%define prefix_openmpi /usr/local/IPM/openmpi-%{openmpiversion}/%{version}
%endif
%if %{with impi}
%global mpi_list %{?mpi_list} intel-mpi
%define prefix_impi /usr/local/IPM/intel-mpi/%{version}
%endif

# modules defaults
%global modulefile_path_top /usr/local/share/Modules/modulefiles/IPM

Version:	2.0.6a
Name:		IPM%( echo %{version} | awk -F. '{printf("%01d%02d%02d",$1,$2,$3)}' )a
Release:	0.%{gittag}.6%{?dist}
Summary:	Integrated Performance Monitoring for HPC

Group:		Development/Libraries
License:	LGPL
URL:		https://github.com/nerscadmin/IPM
Source0:	https://github.com/nerscadmin/%{name}/tarball/%{gittag}/IPM-%{gittag}.tar.gz
Patch1:		ploticus.patch
# https://github.com/nerscadmin/IPM/issues/29
Patch2:		openmpifix.patch

BuildRequires:	gcc automake libtool environment-modules-local
BuildRequires:	zlib-devel systemd-devel libevent-devel papi-devel libunwind-devel

%description
Integrated Performance Monitoring for HPC

%if %{with openmpi}
%package openmpi%{openmpinumversion}
Summary:	Integrated Performance Monitoring for HPC with OpenMPI %{openmpiversion}
Group:		Development/Libraries
Requires:	%{name} papi
BuildRequires:	openmpi-gcc-devel = %{openmpiversion}

%description openmpi%{openmpinumversion}
Integrated Performance Monitoring for HPC with OpenMPI %{openmpiversion}
%endif

%if %{with impi}
%package impi
Summary:	Integrated Performance Monitoring for HPC with Intel MPI
Group:		Development/Libraries
Requires:	%{name} papi
BuildRequires:	intel-mpi-modules-devel = %{intelmpiversion}, intel-mpi-modules-gcc = %{intelmpiversion}

%description impi
Integrated Performance Monitoring for HPC with Intel MPI
%endif

%prep
#%setup -q -n nerscadmin-IPM-%{gittag}
%setup -q -c IPM-%{gittag}
cd nerscadmin-I*
%patch1 -p1
cd ..
for i in %{mpi_list}; do
	cp -ar nerscadmin-I* $i
done
if [ -d openmpi ]; then
cd openmpi
%patch2 -p1
cd ..
fi

%build
# param 1 = dir/module
# param 2 = prefix
build_one() {
	pushd $1
	module load $1
	./bootstrap.sh
	./configure --prefix=$2 --with-papi=/usr --enable-posixio
	make %{?_smp_mflags}
	module purge
	popd
}

%if %{with openmpi}
build_one openmpi %{prefix_openmpi}
%endif

%if %{with impi}
build_one intel-mpi %{prefix_impi}
%endif

%install
# param 1 = dir/module
# param 2 = module name
# param 3 = installation prefix
install_one() {
	pushd $1
	module load $1
	%make_install
	module purge
	popd

	mkdir -p %{buildroot}%{modulefile_path_top}/$2
	cat > %{buildroot}%{modulefile_path_top}/$2/%{version} <<ENDMODULE
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# IPM rpm).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds IPM %{version} for $1 to various paths"
}

module-whatis   "Sets up IPM %{version} for $1 in your environment"
prereq $1

prepend-path PATH "$3/bin"
prepend-path LD_LIBRARY_PATH "$3/lib"
set-alias ipmrun "LD_PRELOAD=$3/lib/libipm.so.0.0.0:$3/lib/libipmf.so.0.0.0 "
if {[module-info shelltype] eq "sh"} {
set-function setupipm {export LD_PRELOAD=$3/lib/libipm.so.0.0.0:$3/lib/libipmf.so.0.0.0 }
set-function removeipm {unset LD_PRELOAD }
}

if {[module-info shelltype] eq "csh"} {
set-alias setupipm {
        setenv LD_PRELOAD $3/lib/libipm.so.0.0.0:$3/lib/libipmf.so.0.0.0
}
set-alias removeipm {
        unsetenv LD_PRELOAD
}
}

# On load print basic instructions
if { [ module-info mode load ] } {
    puts stderr "To run either user setupipm or prefix your command with ipmrun"
    puts stderr "For full run details set IPM_LOG, e.g. export IPM_LOG=full"
}
ENDMODULE
}
%if %{with openmpi}
install_one openmpi openmpi-%{openmpiversion} %{prefix_openmpi}
%endif

%if %{with impi}
install_one intel-mpi intel-mpi %{prefix_impi}
%endif 

find %{buildroot} -name lib*.la -delete

%files
%doc nerscadmin*/AUTHORS nerscadmin*/COPYING nerscadmin*/LICENSE nerscadmin*/NEWS nerscadmin*/README* nerscadmin*/doc

%if %{with openmpi}
%files openmpi%{openmpinumversion}
%{prefix_openmpi}
%dir %{modulefile_path_top}
%dir %{modulefile_path_top}/openmpi-%{openmpiversion}
%{modulefile_path_top}/openmpi-%{openmpiversion}/%{version}
%endif

%if %{with impi}
%files impi
%{prefix_impi}
%dir %{modulefile_path_top}
%dir %{modulefile_path_top}/intel-mpi
%{modulefile_path_top}/intel-mpi/%{version}
%endif

%changelog
* Mon Jan 03 2022 Josko Plazonic <plazonic@princeton.edu>
- initial build
